==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/include/win/WSDwinwinDev.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
// not be used in advertising or otherwise to promote the sale, use or other 
// dealings in this Software without prior written authorization from  
// Toshikaz Hirabayashi.


#ifndef WSDWINWINDEV_H
#define WSDWINWINDEV_H

#include <win/WSDwinformDev.h>

class WSDwinwinDev               :public WSDwinformDev {
  private:
  protected:
//    HWND _shell;
    char   _title_bar_style;
    unsigned _no_frame:1;
    unsigned _requested_top:1;
    unsigned _no_frame_first_time:1;
    unsigned _popup_parent:1;
    unsigned _float_on_top:1;
    unsigned _modal:1;
    unsigned _destroyed_by_method:1;
//    long     _diff_x;
//    long     _diff_y;
    long     _x_now;
    long     _y_now;
    long     _diff_w;
    long     _diff_h;
    HWND     _shell;
    long     _style;
    long     _style_ex;
    char*    _title_string;
    virtual long createWindow();
    virtual long destroyWindow();
   
virtual    void _evh_client_message(WinEvent* );
virtual    void _evh_delete(WinEvent* );
virtual    void _evh_resize(WinEvent* );
virtual    void _evh_move(WinEvent* );
virtual    void _evh_expose(WinEvent* );
virtual    void _evh_focus_ch(WinEvent* );
virtual    void _evh_mouse_in(WinEvent* );

#if 0
static void _float_top_timer_proc(WSCuchar,void*);
static WSClistData  _no_frame_list;
static void _add_list(WSDwinwinDev*);
static void _del_list(WSDwinwinDev*);
static void _popup_window(WSDwinwinDev*);
static WSCbool _chk_popup(WSDwinwinDev*);
#endif
  public:
    WSDwinwinDev();
    virtual ~WSDwinwinDev();
    virtual long setVisible(WSCbool fl);
    virtual long setValue(long kind,void*);
    virtual long getValue(long kind,void*);
    virtual WSDdev* getParentDev();
    virtual WSDdev* getVisibleParentDev();
    virtual long dispatchEvent(WinEvent*);
//    HWND getShell();
    WSMFclassDef(WSDwinwinDev,WSDwinformDev);
};
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/win/WSDwinwinDev.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.


#ifndef WSDWINWINDEV_H
#define WSDWINWINDEV_H

#include <win/WSDwinformDev.h>

class WSDwinwinDev               :public WSDwinformDev {
  private:
  protected:
    HWND _rebase_handle;
    char   _title_bar_style;
    unsigned _no_frame:1;
    unsigned _requested_top:1;
    unsigned _no_frame_first_time:1;
    unsigned _popup_parent:1;
    unsigned _float_on_top:1;
    unsigned _modal:1;
    unsigned _destroyed_by_method:1;
//    long     _diff_x;
//    long     _diff_y;
    long     _x_now;
    long     _y_now;
    long     _diff_w;
    long     _diff_h;
    HWND     _shell;
    long     _style;
    long     _style_ex;
    char*    _title_string;
    WSDLEX32 virtual long createWindow();
    WSDLEX32 virtual long destroyWindow();
   
WSDLEX32 virtual    long _evh_delete(WinEvent* );
WSDLEX32 virtual    void _evh_resize(WinEvent* );
WSDLEX32 virtual    void _evh_move(WinEvent* );
WSDLEX32 virtual    void _evh_expose(WinEvent* );
WSDLEX32 virtual    void _evh_focus_ch(WinEvent* );
WSDLEX32 virtual    void _evh_mouse_in(WinEvent* );

#if 0
static void _float_top_timer_proc(WSCuchar,void*);
static WSClistData  _no_frame_list;
static void _add_list(WSDwinwinDev*);
static void _del_list(WSDwinwinDev*);
static void _popup_window(WSDwinwinDev*);
static WSCbool _chk_popup(WSDwinwinDev*);
#endif
  public:
    WSDLEX32 WSDwinwinDev();
    WSDLEX32 virtual ~WSDwinwinDev();
    WSDLEX32 virtual long setVisible(WSCbool fl);
    WSDLEX32 virtual long setValue(long kind,void*);
    WSDLEX32 virtual long getValue(long kind,void*);
    WSDLEX32 virtual WSDdev* getParentDev();
    WSDLEX32 virtual WSDdev* getVisibleParentDev();
    WSDLEX32 virtual long dispatchEvent(WinEvent*);

#ifndef NO_MWT_FUNCTION
    WSDLEX32 virtual void getDiffCoordinates(long*,long*);
    WSDLEX32 HWND getRebaseHandle();
#endif

//    HWND getShell();
    WSMFclassDef(WSDwinwinDev,WSDwinformDev);
};
#endif
